Function insert_breadcrumb_deduped
pub fn insert_breadcrumb_deduped(history: &mut Vec<ChatMessage>)Expand description
Insert the trim breadcrumb after the leading system messages, unless one is already sitting there.
pub fn insert_breadcrumb_deduped(history: &mut Vec<ChatMessage>)Insert the trim breadcrumb after the leading system messages, unless one is already sitting there.