ChannelIdentityNormalizer

Type Alias ChannelIdentityNormalizer 

pub type ChannelIdentityNormalizer = fn(&str) -> String;
Per-channel-type identity normalizer. The operator-bind op is otherwise identical across the pairing-capable channels; the only variance is how a raw identity is canonicalized before it is stored in the allowlist.