Function run
pub async fn run(suite: PathBuf, mode: Mode) -> Result<SuiteReport>Expand description
Run a suite of eval cases and return the aggregated report.
pub async fn run(suite: PathBuf, mode: Mode) -> Result<SuiteReport>Run a suite of eval cases and return the aggregated report.