pub struct MapPathQuery {
pub path: String,
}Fields
path: StringTrait Implementations
Sourceimpl Debug for MapPathQuery
impl Debug for MapPathQuery
Sourceimpl<'de> Deserialize<'de> for MapPathQuery
impl<'de> Deserialize<'de> for MapPathQuery
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MapPathQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MapPathQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MapPathQuery
impl JsonSchema for MapPathQuery
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MapPathQuery
impl RefUnwindSafe for MapPathQuery
impl Send for MapPathQuery
impl Sync for MapPathQuery
impl Unpin for MapPathQuery
impl UnsafeUnpin for MapPathQuery
impl UnwindSafe for MapPathQuery