Struct SlashOptionKindsResult
pub struct SlashOptionKindsResult {
pub kinds: Vec<SlashOptionKindDescriptor>,
}Expand description
Response for GET /api/skills/slash-option-kinds: the canonical registry,
built by walking SlashOptionKind::ALL.
Fields
kinds: Vec<SlashOptionKindDescriptor>Trait Implementations
Sourceimpl Debug for SlashOptionKindsResult
impl Debug for SlashOptionKindsResult
Sourceimpl JsonSchema for SlashOptionKindsResult
impl JsonSchema for SlashOptionKindsResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SlashOptionKindsResult
impl Serialize for SlashOptionKindsResult
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more