AuthService

Struct AuthService 

pub struct AuthService { /* private fields */ }

Implementations

Source

impl AuthService

pub fn from_config(config: &Config) -> AuthService

pub fn new(state_dir: &Path, encrypt_secrets: bool) -> AuthService

pub async fn load_profiles(&self) -> Result<AuthProfilesData, Error>

pub async fn store_openai_tokens( &self, profile_name: &str, token_set: TokenSet, account_id: Option<String>, set_active: bool, ) -> Result<AuthProfile, Error>

pub async fn store_gemini_tokens( &self, profile_name: &str, token_set: TokenSet, account_id: Option<String>, set_active: bool, ) -> Result<AuthProfile, Error>

pub async fn store_model_provider_token( &self, model_provider: &str, profile_name: &str, token: &str, metadata: HashMap<String, String>, set_active: bool, ) -> Result<AuthProfile, Error>

pub async fn set_active_profile( &self, model_provider: &str, requested_profile: &str, ) -> Result<String, Error>

pub async fn remove_profile( &self, model_provider: &str, requested_profile: &str, ) -> Result<bool, Error>

pub async fn get_profile( &self, model_provider: &str, profile_override: Option<&str>, ) -> Result<Option<AuthProfile>, Error>

pub async fn get_provider_bearer_token( &self, model_provider: &str, profile_override: Option<&str>, ) -> Result<Option<String>, Error>

pub async fn get_valid_openai_access_token( &self, profile_override: Option<&str>, ) -> Result<Option<String>, Error>

pub async fn get_valid_gemini_access_token( &self, profile_override: Option<&str>, client_id: &str, client_secret: &str, ) -> Result<Option<String>, Error>

Get a valid Gemini OAuth access token, refreshing if necessary.

client_id and client_secret are the OAuth app credentials from the per-alias [model_providers.gemini.<alias>] typed config — required when a refresh is triggered. Required when the cached access token is near expiry; ignored when the access token is still valid. Pass empty strings only if the caller is certain the token won’t need refresh in this call.

Returns None if no Gemini profile exists.

pub async fn get_gemini_profile( &self, profile_override: Option<&str>, ) -> Result<Option<AuthProfile>, Error>

Get Gemini profile info (for model_provider initialization).