Struct ConditionField
pub struct ConditionField {
pub path: String,
pub label: String,
pub value_type: ConditionValueType,
pub options: Vec<String>,
}Expand description
One field of a trigger payload a condition can reference. path is the
JSON path suffix after $. (empty for a scalar payload compared directly),
label is the human name, value_type drives the value control, and
options carries the choices when value_type is Enum.
Fields
path: Stringlabel: Stringvalue_type: ConditionValueTypeoptions: Vec<String>Trait Implementations
Sourceimpl Clone for ConditionField
impl Clone for ConditionField
Sourcefn clone(&self) -> ConditionField
fn clone(&self) -> ConditionField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConditionField
impl Debug for ConditionField
Sourceimpl<'de> Deserialize<'de> for ConditionField
impl<'de> Deserialize<'de> for ConditionField
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ConditionField, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ConditionField, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConditionField
impl JsonSchema for ConditionField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConditionField
impl PartialEq for ConditionField
Sourceimpl Serialize for ConditionField
impl Serialize for ConditionField
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for ConditionField
impl StructuralPartialEq for ConditionField