Struct TriggerField
pub struct TriggerField {
pub name: String,
pub options: Vec<String>,
pub multi: bool,
pub kind: TriggerFieldKind,
}Expand description
One editable field of a trigger source (e.g. topic for MQTT).
Fields
name: Stringoptions: Vec<String>multi: boolkind: TriggerFieldKindTrait Implementations
Sourceimpl Clone for TriggerField
impl Clone for TriggerField
Sourcefn clone(&self) -> TriggerField
fn clone(&self) -> TriggerField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TriggerField
impl Debug for TriggerField
Sourceimpl<'de> Deserialize<'de> for TriggerField
impl<'de> Deserialize<'de> for TriggerField
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TriggerField, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TriggerField, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TriggerField
impl JsonSchema for TriggerField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TriggerField
impl PartialEq for TriggerField
Sourceimpl Serialize for TriggerField
impl Serialize for TriggerField
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for TriggerField
impl StructuralPartialEq for TriggerField