pub struct AcpServer { /* private fields */ }Implementations
Sourceimpl AcpServer
impl AcpServer
pub fn new(config: Config, acp_config: AcpServerConfig) -> AcpServer
pub fn new_with_writer( config: Config, acp_config: AcpServerConfig, writer_tx: Sender<String>, ) -> AcpServer
pub fn new_with_store( config: Config, acp_config: AcpServerConfig, store: Arc<AcpSessionStore>, ) -> AcpServer
pub fn new_with_writer_and_store( config: Config, acp_config: AcpServerConfig, writer_tx: Sender<String>, store: Arc<AcpSessionStore>, ) -> AcpServer
Sourcepub fn with_canvas_store(self, canvas_store: CanvasStore) -> AcpServer
pub fn with_canvas_store(self, canvas_store: CanvasStore) -> AcpServer
Attach the shared gateway CanvasStore so that agents created by
this server write canvas frames to the same store that the
/ws/canvas/:id WebSocket endpoint serves.
Sourcepub async fn run(self: Arc<AcpServer>) -> Result<(), Error>
pub async fn run(self: Arc<AcpServer>) -> Result<(), Error>
Run the ACP server, reading JSON-RPC requests from stdin and writing responses/notifications to stdout.
Sourcepub async fn run_messages(
self: Arc<AcpServer>,
input_rx: Receiver<String>,
) -> Result<(), Error>
pub async fn run_messages( self: Arc<AcpServer>, input_rx: Receiver<String>, ) -> Result<(), Error>
Run the ACP server against an already-framed line source.
This is used by the gateway WebSocket bridge, where inbound WebSocket
text messages are already complete JSON-RPC frames and outbound frames
are supplied by the writer channel passed to Self::new_with_writer
or Self::new_with_writer_and_store.